@@ -29,6 +29,8 @@ class Context:
 
     socket: Optional[Any]
 
+    parameters: Dict[str, str] # the server/client parameters e.g client_encoding
+
     def update_mem(self, k, v):
         return Context(input=self.input, output=self.output,
                        session=self.session,
@@ -40,4 +42,5 @@ class Context:
                        portals=self.portals,
                        key_file=self.key_file,
                        cert_file=self.cert_file,
-                       socket=self.socket)
+                       socket=self.socket,
+                       parameters=self.parameters)
