@@ -10,7 +10,7 @@ from pypsql_api.wire.actions_types import Names
 from pypsql_api.context import Context
 from pypsql_api.wire.back import SSLNo, AuthenticationCleartextPassword, ReadyForQuery, AuthenticationOk, \
     EmptyQueryResponse, DataFrameRowDescription, DataFrameDataRows, CommandComplete, SSLYes, ErrorResponse, \
-    ParameterStatus
+    ParameterStatus, CloseComplete
 from pypsql_api.wire.bytes import ReadingIO, WritingIO
 from pypsql_api.wire.errors.core import log_exception, NoData
 from pypsql_api.wire.front import SSLRequest, StartupMessage, Message, PasswordMessage
@@ -194,11 +194,20 @@ def read_receive_extended_command(context: Context):
         logging.info(f"Not m,t  {m}, {t}")
         return context, None
 
-    if m and m.process_name in {Names.EXECUTE, Names.BIND, Names.SYNC, Names.DESCRIBE}:
-        return context.update_mem('message', m), m.process_name
+    if m:
+        if m.process_name in {Names.EXECUTE, Names.BIND, Names.SYNC, Names.DESCRIBE}:
+            return context.update_mem('message', m), m.process_name
+        elif m.process_name == {Names.CLOSE, Names.FLUSH}:
+            logging.error(f"###### ignoring {m} inside extended query sequence ######")
+
+            if m.process_name == Names.CLOSE:
+                CloseComplete().write(context.output)
+
+            return context, Names.RECEIVE_EXTENDED_QUERY_COMMAND
 
     logging.info(f"Expected an extended protocol query message but got {m}, {t}")
-    return context, Names.ERROR
+
+    return context, Names.SYNC
 
 
 def write_empty_response(context: Context):
