@@ -131,6 +131,14 @@ class EmptyQueryResponse:
         buff.write_int32(4)
 
 
+@dataclass
+class CloseComplete:
+    tag: str
+
+    def write(self, buff: WritingIO):
+        buff.write_byte(ord('3'))
+        buff.write_int32(4)
+
 @dataclass
 class CommandComplete:
     tag: str
