@@ -220,6 +220,23 @@ class Describe:
         return Describe(t=t, name=name)
 
 
+@dataclass
+class Close:
+    t: str  # 'S == close prepared statement, P == close portal
+    name: str
+
+    process_name: Any = Names.CLOSE
+
+    @staticmethod
+    def read_body(buff: ReadingIO):
+        t = buff.read_byte()
+        name = buff.read_cstring()
+        if not name:
+            name = 'UNNAMED'
+
+        return Close(t=t, name=name)
+
+
 message_type_map = {
     ord('p'): PasswordMessage.read_body,
     ord('Q'): QueryMessage.read_body,
@@ -230,6 +247,7 @@ message_type_map = {
     ord('H'): Flush.read_body,
     ord('S'): Sync.read_body,
     ord('D'): Describe.read_body,
+    ord('C'): Close.read_body,
 }
 
 
