@@ -135,13 +135,13 @@ def run_states(context, state_name):
     while state_name != Names.CLOSE:
         context, state_name = run_state(context, state_name)
 
-    logging.info("End run states")
+    logging.error("End run states")
 
     return context, state_name
 
 
 def run_state(context, state_name):
-    logging.info(f"Running state {state_name}")
+    logging.error(f"Running state {state_name}")
     state = processes.get(state_name)
 
     if hasattr(context.output, 'flush'):
