@@ -128,18 +128,22 @@ def process_parse_command(context: Context):
                     return context, Names.RECEIVE_EXTENDED_QUERY_COMMAND
                 else:
                     logging.error(f"Error: {resp} {error_msg}")
-                    return context, Names.CLOSE
+                    ErrorResponse().write(context.output)
+                    return context, Names.SYNC
             except Exception as e:
                 log_exception(e)
-                return context, Names.CLOSE
+                ErrorResponse().write(context.output)
+                return context, Names.SYNC
 
         else:
-            logging.error("Closing from Parse no query")
-            return context, Names.CLOSE
+            logging.error("Empty Query Sent")
+            ParseComplete().write(context.output)
+            return context, Names.RECEIVE_EXTENDED_QUERY_COMMAND
     except Exception as e:
         log_exception(e)
         logging.error(f"Error when parsing {msg}")
-        return context, Names.CLOSE
+        ErrorResponse().write(context.output)
+        return context, Names.SYNC
     finally:
         logging.info("######################################################")
 
